package com.sun.tools.javap.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "20.0.2-internal-adhoc.root.jdk20u-jdk-20.0.2-ga" },
            { "jdk", "20.0.2" },
            { "release", "20.0.2-internal" },
        };
    }
}
